pub struct GitHubCodeDestination {
pub description: Option<String>,
pub issues_enabled: bool,
pub name: String,
pub owner: String,
pub private_repository: bool,
pub token: String,
pub type_: String,
}Expand description
Information about the GitHub repository to be created in AWS CodeStar. This is where the source code files provided with the project request will be uploaded after project creation.
Fields
description: Option<String>Description for the GitHub repository to be created in AWS CodeStar. This description displays in GitHub after the repository is created.
issues_enabled: boolWhether to enable issues for the GitHub repository.
name: StringName of the GitHub repository to be created in AWS CodeStar.
owner: StringThe GitHub username for the owner of the GitHub repository to be created in AWS CodeStar. If this repository should be owned by a GitHub organization, provide its name.
private_repository: boolWhether the GitHub repository is to be a private repository.
token: StringThe GitHub user's personal access token for the GitHub repository.
type_: StringThe type of GitHub repository to be created in AWS CodeStar. Valid values are User or Organization.